@@ -27,6 +27,8 @@ KEY_FILE = "E:\\xpra.pfx"
 DIST = "dist"
 LIB_DIR = f"{DIST}/lib"
 
+ARCH = os.environ.get("MSYSTEM_CARCH", "")
+
 DEBUG = os.environ.get("XPRA_DEBUG", "0") != "0"
 PYTHON = os.environ.get("PYTHON", "python%i.%i" % sys.version_info[:2])
 MINGW_PREFIX = os.environ.get("MINGW_PREFIX", "")
@@ -84,8 +86,8 @@ def parse_command_line(argv: list[str]):
     add("tests", help="run the unit tests", default=False)
     add("zip-modules", help="zip up python modules")
     add("cuda", help="build CUDA kernels for nvidia codecs")
-    add("service", help="build the system service")
-    add("docs", help="generate the documentation")
+    add("service", help="build the system service", default=ARCH != "aarch64")
+    add("docs", help="generate the documentation", default=ARCH != "aarch64")
     add("html5", help="bundle the `xpra-html5` client")
     add("manual", help="bundle the user manual")
     add("numpy", help="bundle `numpy`")
@@ -94,6 +96,7 @@ def parse_command_line(argv: list[str]):
     add("openssl", help="bundle the openssl tools")
     add("paexec", help="bundle `paexec`")
     add("desktop-logon", help="build `desktop-logon` tool")
+    ap.add_argument("--build-args", default="", help="extra build arguments")
 
     args, unknown_args = ap.parse_known_args(argv)
     if args.light:
@@ -128,12 +131,12 @@ def du(path: str) -> int:
 
 
 def get_build_args(args) -> list[str]:
-    xpra_args = []
+    xpra_args = ["--without-gstreamer_video"]
     if args.light:
         for option in (
             "shadow", "server", "proxy", "rfb",
             "dbus",
-            "encoders", "avif", "gstreamer_video",
+            "encoders", "avif",
             "nvfbc", "cuda_kernels",
             "csc_cython",
             "webcam",
@@ -147,6 +150,8 @@ def get_build_args(args) -> list[str]:
         xpra_args.append("--with-qt6_client")
     if not args.cuda:
         xpra_args.append("--without-nvidia")
+    if args.build_args:
+        xpra_args += shlex.split(args.build_args)
     # we can't do 'docs' this way :(
     # for arg in ("docs", ):
     #    value = getattr(args, arg)
@@ -158,6 +163,9 @@ def _find_command(name: str, env_name: str, *paths) -> str:
     cmd = os.environ.get(env_name, "")
     if cmd and os.path.exists(cmd):
         return cmd
+    cwd_cmd = os.path.abspath(f"./{name}.exe")
+    if os.path.exists(cwd_cmd):
+        return cwd_cmd
     cmd = which(name)
     if cmd and os.path.exists(cmd):
         return cmd
@@ -221,9 +229,10 @@ def check_html5() -> None:
 
 def check_signtool() -> None:
     step("locating `signtool`")
+    if os.path.exists("./signtool.exe"):
+        return
     try:
         signtool = find_command("signtool", "SIGNTOOL",
-                                "./signtool.exe",
                                 f"{PROGRAMFILES}\\Microsoft SDKs\\Windows\\v7.1\\Bin\\signtool.exe"
                                 f"{PROGRAMFILES}\\Microsoft SDKs\\Windows\\v7.1A\\Bin\\signtool.exe"
                                 f"{PROGRAMFILES_X86}\\Windows Kits\\8.1\\Bin\\x64\\signtool.exe"
@@ -236,8 +245,7 @@ def check_signtool() -> None:
         if not signtool:
             raise RuntimeError("signtool not found")
     debug(f"{signtool=}")
-    if signtool.lower() != "./signtool.exe":
-        copyfile(signtool, "./signtool.exe")
+    copyfile(signtool, "./signtool.exe")
 
 
 def show_tail(filename: str) -> None:
@@ -323,6 +331,10 @@ def clean() -> None:
 
 
 def find_windowskit_command(name="mc") -> str:
+    debug(f"find_windowskit_command({name!r})")
+    cwd_cmd = os.path.abspath(f"./{name}.exe")
+    if os.path.exists(cwd_cmd):
+        return cwd_cmd
     # the proper way would be to run vsvars64.bat
     # but we only want to locate 3 commands,
     # so we find them "by hand":
@@ -337,10 +349,13 @@ def find_windowskit_command(name="mc") -> str:
 
 
 def find_vs_command(name="link") -> str:
-    debug(f"find_vs_command({name})")
+    debug(f"find_vs_command({name!r})")
+    cwd_cmd = os.path.abspath(f"./{name}.exe")
+    if os.path.exists(cwd_cmd):
+        return cwd_cmd
     dirs = []
     for prog_dir in (PROGRAMFILES, PROGRAMFILES_X86):
-        for VSV in (14.0, 17.0, 19.0, 2019):
+        for VSV in (14.0, 17.0, 19.0, 2019, 2022):
             vsdir = f"{prog_dir}\\Microsoft Visual Studio\\{VSV}"
             if os.path.exists(vsdir):
                 dirs.append(f"{vsdir}\\VC\\bin")
@@ -374,7 +389,7 @@ VersionInfo = namedtuple("VersionInfo", "string,value,revision,full_string,arch_
 version_info = VersionInfo("invalid", (0, 0), 0, "invalid", "arch", "extra", (0, 0, 0, 0))
 
 
-def set_version_info(light: bool):
+def set_version_info(light: bool) -> None:
     step("Collecting version information")
     for filename in ("src_info.py", "build_info.py"):
         path = os.path.join("xpra", filename)
@@ -384,7 +399,7 @@ def set_version_info(light: bool):
     load_version_info(light)
 
 
-def load_version_info(light: bool):
+def load_version_info(light: bool) -> None:
 
     def load_module(src: str):
         spec = spec_from_file_location("xpra", src)
@@ -1182,7 +1197,7 @@ def export_sbom() -> None:
 def verpatch() -> None:
     EXCLUDE = ("plink", "openssh", "openssl", "paexec")
 
-    def run_verpatch(filename: str, descr: str):
+    def run_verpatch(filename: str, descr: str) -> None:
         log_command(["verpatch", filename,
                      "/s", "desc", descr,
                      "/va", version_info.padded,
@@ -1390,7 +1405,7 @@ def build(args) -> None:
                 sign_file(msi)
 
 
-def main(argv):
+def main(argv) -> None:
     args, unknownargs = parse_command_line(argv)
     if len(unknownargs) > 1:
         if len(unknownargs) != 2:
