@@ -6,8 +6,8 @@
 
 import unittest
 
-from xpra.util import AdHocStruct, typedict
-from xpra.client.base.serverinfo_mixin import ServerInfoMixin
+from xpra.util.objects import typedict, AdHocStruct
+from xpra.client.base.serverinfo import ServerInfoMixin
 from unit.client.mixins.clientmixintest_util import ClientMixinTest
 
 
